<?php
class slWidgetsettings extends slWidget
{
	public function create($sID)
	{
		die('s');
	}
}
?>